@@ -2,7 +2,9 @@ pub mod array_set;
 pub mod base64;
 pub mod base64_vlq;
 pub mod binary_search;
+pub mod constants;
 pub mod consumer;
+mod consumer_test;
 pub mod generator;
 pub mod mapping;
 pub mod mapping_list;
